# _AFQ-Insight_ Python based statistical learning for tractometry

[![Build Status](https://github.com/richford/AFQ-Insight/workflows/Build/badge.svg)](https://github.com/richford/AFQ-Insight/workflows/Build/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/richford/AFQ-Insight/badge.svg?branch=main&service=github)](https://coveralls.io/github/richford/AFQ-Insight?branch=main&service=github)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/python/black)
[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3585942.svg)](https://doi.org/10.5281/zenodo.3585942)

See <https://yeatmanlab.github.io/AFQ-Browser/> for documentation of the AFQ data format

This is a work in progress.

## Contributing

We love contributions! _AFQ-Insight_ is open source, built on open source,
and we'd love to have you hang out in our community.

We have developed some [guidelines](.github/CONTRIBUTING.md) for contributing to
_AFQ-Insight_.

## Citing _AFQ-Insight_

If you use _AFQ-Insight_ in a scientific publication, please see cite us:

Richie-Halford, A., Yeatman, J., Simon, N., and Rokem, A.
[Multidimensional analysis and detection of informative features in diffusion MRI measurements of human white matter][link_afqinsight_preprint].
DOI:10.1101/2019.12.19.882928

```
@article {Richie-Halford2019.12.19.882928,
	author = {{R}ichie-{H}alford, {A}dam and {Y}eatman, {J}ason and {S}imon, {N}oah and {R}okem, {A}riel},
	title = {{M}ultidimensional analysis and detection of informative features in diffusion {MRI} measurements of human white matter},
	elocation-id = {2019.12.19.882928},
	year = {2019},
	doi = {10.1101/2019.12.19.882928},
	publisher = {Cold Spring Harbor Laboratory},
	URL = {https://www.biorxiv.org/content/early/2019/12/20/2019.12.19.882928},
	eprint = {https://www.biorxiv.org/content/early/2019/12/20/2019.12.19.882928.full.pdf},
	journal = {bioRxiv}
}
```

## Acknowledgements

_AFQ-Insight_ development is supported through a grant from the [Gordon
and Betty Moore Foundation](https://www.moore.org/) and from the
[Alfred P. Sloan Foundation](https://sloan.org/) to the [University of
Washington eScience Institute](http://escience.washington.edu/), as
well as
[NIMH BRAIN Initiative grant 1RF1MH121868-01](https://projectreporter.nih.gov/project_info_details.cfm?aid=9886761&icde=46874320&ddparam=&ddvalue=&ddsub=&cr=2&csb=default&cs=ASC&pball=)
to Ariel Rokem (University of Washington).

[link_afqinsight_preprint]: https://doi.org/10.1101/2019.12.19.882928 